@@ -36,6 +36,7 @@ use Test::Stream::Compare::Regex;
 use Test::Stream::Compare::Scalar;
 use Test::Stream::Compare::Set;
 use Test::Stream::Compare::String;
+use Test::Stream::Compare::Undef;
 use Test::Stream::Compare::Value;
 use Test::Stream::Compare::Wildcard;
 
@@ -136,21 +137,25 @@ sub validator {
     );
 }
 
-sub number($) {
+sub number($;@) {
+    my ($num, @args) = @_;
     my @caller = caller;
     return Test::Stream::Compare::Number->new(
         file  => $caller[1],
         lines => [$caller[2]],
-        input => $_[0],
+        input => $num,
+        @args,
     );
 }
 
-sub string($) {
+sub string($;@) {
+    my ($str, @args) = @_;
     my @caller = caller;
     return Test::Stream::Compare::String->new(
         file  => $caller[1],
         lines => [$caller[2]],
-        input => $_[0],
+        input => $str,
+        @args,
     );
 }
 
@@ -363,6 +368,9 @@ sub event($;$) {
 sub convert {
     my ($thing, $strict) = @_;
 
+    return Test::Stream::Compare::Undef->new()
+        unless defined $thing;
+
     if ($thing && blessed($thing) && $thing->isa('Test::Stream::Compare')) {
         return $thing unless $thing->isa('Test::Stream::Compare::Wildcard');
         my $newthing = convert($thing->expect, $strict);
@@ -692,7 +700,7 @@ you can specify a name and operator that are used in diagnostics, they are also
 provided to the sub itself as named parameters.
 
 Check the value using this sub. The sub gets the value in C<$_>, as well it
-recieved the value and several other items as named parameters.
+received the value and several other items as named parameters.
 
     my $check = validator(sub {
         my %params = @_;
