@@ -21,18 +21,6 @@ __END__
 
 Test::Stream::Plugin::Context - Plugin to expose the context function.
 
-=head1 EXPERIMENTAL CODE WARNING
-
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
-
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
-
 =head1 DESCRIPTION
 
 This plugin exposes the C<context()> function. This function is used by tools
@@ -41,7 +29,7 @@ generating test events.
 
 =head1 SYNOPSIS
 
-    use Test::Stream qw/-V1 Context/;
+    use Test::Stream qw/... Context/;
 
     sub my_tool {
         my $ctx = context();
