@@ -338,15 +338,11 @@ implementations that all play nicely together.
 
 =head1 EXPERIMENTAL CODE WARNING
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
-
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+C<This module is still EXPERIMENTAL>. Test-Stream is now stable, but this
+particular module is still experimental. You are still free to use this module,
+but you have been warned that it may change in backwords incompatible ways.
+This message will be removed from this modules POD once it is considered
+stable.
 
 =head1 DESCRIPTION
 
